Stan Math Library: Eigen::internal::scalar_product_traits< stan::math::var, double > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
Eigen::internal::scalar_product_traits< stan::math::var, double > Struct Template Reference

Scalar product traits override for Eigen for automatic gradient variables. More...

`#include <Eigen_NumTraits.hpp>`

## Public Types
typedef stan::math::var | ReturnType

## Detailed Description

### template<>
struct Eigen::internal::scalar_product_traits< stan::math::var, double >

Scalar product traits override for Eigen for automatic gradient variables.

Definition at line 111 of file Eigen_NumTraits.hpp.

## Member Typedef Documentation

typedef stan::math::var Eigen::internal::scalar_product_traits< stan::math::var, double >::ReturnType

Definition at line 112 of file Eigen_NumTraits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/mat/fun/Eigen_NumTraits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.